@@ -29,7 +29,6 @@
 
 from collections import OrderedDict
 import copy
-import re
 import yaml
 
 from plugin.pb2 import resource_pb2
@@ -188,13 +187,6 @@ def create_gapic_config_v2(gapic_v2, request):  # noqa: C901
             if res.type:
                 update_collections(res, collections, collection_oneofs)
 
-    # Load deprecated_collections.
-    update_collections_with_deprecated_resources(
-        gapic_v2,
-        pattern_resource_map,
-        collections,
-        collection_oneofs)
-
     single_resource_names, fixed_resource_names = \
         find_single_and_fixed_entities(collections.values())
 
@@ -376,84 +368,6 @@ def update_collections(res, collections, collection_oneofs):
     # pylint: enable=no-member
 
 
-def _get_resource_for_deprecate_pattern(
-        deprecated_collection_pattern,
-        pattern_resource_map):
-    resources = pattern_resource_map[deprecated_collection_pattern]
-    resources = [r for r in resources if len(r.pattern) > 1]
-
-    # A deprecated collection pattern belonging to multiple resources
-    # is very unlikely and cannot be nicely handled by resource
-    # name design in GAPIC v1(as the parent resource class is an
-    # abstract class rather than an interface, and Java does not
-    # have multiple inheritence).
-    if len(resources) > 1:
-        raise ValueError('Not supported: pattern of a deprecated '
-                         'collections belongs to multiple resources: '
-                         '{}'.format(deprecated_collection_pattern))
-    if not resources:
-        raise ValueError('Not supported: deprecating a single-pattern'
-                         'resource name.')
-    resource = resources[0]
-    if len(resource.pattern) <= 1:
-        raise ValueError('deprecated collection point to a '
-                         'single-pattern resource: {}'.format(
-                             resource.type))
-    return resource
-
-
-def update_collections_with_deprecated_resources(
-        gapic_v2,
-        pattern_resource_map,
-        collections,
-        collection_oneofs):
-    for interface in gapic_v2.get('interfaces', ()):
-        if 'deprecated_collections' not in interface:
-            continue
-        for deprecated_collection in interface['deprecated_collections']:
-            if 'entity_name' not in deprecated_collection:
-                raise ValueError('entity_name is required '
-                                 'in a deprecated_collection.')
-            if 'name_pattern' not in deprecated_collection:
-                raise ValueError('name_pattern is required '
-                                 'in a deprecated_collection.')
-
-            entity_name = deprecated_collection['entity_name']
-            name_pattern = deprecated_collection['name_pattern']
-
-            if entity_name not in collections:
-                collections[entity_name] = deprecated_collection
-            if name_pattern not in pattern_resource_map:
-                raise ValueError(
-                    'deprecated collection has '
-                    'an unknown name pattern: {}'.format(name_pattern))
-            resource = _get_resource_for_deprecate_pattern(
-                name_pattern, pattern_resource_map)
-            oneof_name = to_snake(resource.type.split('/')[-1]) + '_oneof'
-            if oneof_name not in collection_oneofs:
-                raise ValueError(
-                    'internal: multi-pattern resource not added to '
-                    'collection_oneofs: {}'.format(oneof_name))
-            collection_oneofs[oneof_name]['collection_names'].append(
-                entity_name)
-
-
-def calculate_pattern_entity_name(ptn):
-
-    if isFixedPattern(ptn):
-        start_index = next(i for (i, c) in enumerate(list(ptn)) if c.isalpha())
-        end_index = len(ptn) - next(
-            i for (i, c) in enumerate(list(ptn)[::-1]) if c.isalpha())
-        name_parts = re.split(r'[^a-zA-Z]', ptn[start_index:end_index])
-        return '_'.join(name_parts)
-    else:
-        segs = []
-        for seg in ptn.split('/'):
-            if _is_variable_segment(seg):
-                segs.append(to_snake(seg[1:-1]))
-        return '_'.join(segs)
-
-
 def build_parent_patterns(patterns):
     def _parent_pattern(pattern):
         segs = pattern.split('/')
@@ -510,9 +424,9 @@ def load_collection_configs(config_list, existing_configs):
                     'Found collection configs with same entity name '
                     'but different patterns. Name: ' + entity_name)
         else:
-            existing_configs[entity_name] = CollectionConfig(entity_name,
-                                                             name_pattern,
-                                                             java_entity_name)
+            existing_configs[entity_name] = \
+                CollectionConfig(entity_name, name_pattern,
+                                 java_entity_name)
     return existing_configs
 
 
